@@ -1,18 +1,7 @@
-# $Id$
 
 package Google::Chart::Title;
 use Moose;
-use Google::Chart::Types;
-use Moose::Util::TypeConstraints;
-
-coerce 'Google::Chart::Title'
-    => from 'HashRef'
-    => via {
-        Google::Chart::Title->new(%$_);
-    }
-;
-
-with 'Google::Chart::QueryComponent';
+use namespace::clean -except => qw(meta);
 
 has 'text' => (
     is => 'rw',
@@ -30,10 +19,6 @@ has 'fontsize' => (
     isa => 'Num'
 );
 
-__PACKAGE__->meta->make_immutable;
-
-no Moose;
-
 sub as_query {
     my $self = shift;
 
@@ -52,10 +37,11 @@ sub as_query {
         );
     }
 
-    return wantarray ? %data : 
-        join('&', map { "$_=$data{$_}" } keys %data );
+    return %data;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
